@@ -95,9 +95,6 @@ bool MenuFile::save()
         return false;
     }
     QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    stream.setCodec("UTF-8");
-#endif
 
     stream << m_doc.toString();
 
